web

package
v0.6.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 13, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Overview

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

templ: version: v0.3.1001

Index

Constants

const (
	AlertsTitle          = "Alerts"
	AnalyticsTitle       = "Analytics"
	IssueDetailsTitle    = "Issue Details"
	IssuesTitle          = "Issues"
	OnCallTitle          = "OnCall"
	NewProjectTitle      = "New project"
	ProjectOverviewTitle = "Project overview"
	ReportsTitle         = "Reports"
	SettingsTitle        = "Settings"
	ProjectsTitle        = "Projects"
	ProjectSettingsTitle = "Project settings"
	SchemaTitle          = "Schema"
	QueriesTitle         = "Queries"
	AnalyticsErrorTitle  = "Errors"
	InternalErrorTitle   = "Internal Error"
)
const AppName = "Warnly"

Variables

This section is empty.

Functions

func AddNewAlert added in v0.5.0

func AddNewAlert(user *warnly.User, projects []warnly.Project) templ.Component

func AddNewAlertContent added in v0.5.0

func AddNewAlertContent(user *warnly.User, projects []warnly.Project) templ.Component

func AddNewAlertHtmx added in v0.5.0

func AddNewAlertHtmx(user *warnly.User, projects []warnly.Project) templ.Component

func Alerts added in v0.5.0

Alerts is the main template that includes filters header and alert list body

func AlertsBody added in v0.5.0

func AlertsBody(res *warnly.ListAlertsResult) templ.Component

AlertsBody - the alerts list and pagination that gets updated via HTMX

func AlertsFiltersAndBody added in v0.5.0

func AlertsFiltersAndBody(res *warnly.ListAlertsResult) templ.Component

AlertsFiltersAndBody contains the filters and the body - used for HTMX updates

func AlertsHtmx added in v0.5.0

func AlertsHtmx(res *warnly.ListAlertsResult) templ.Component

func AnalyticStoreErrors

func AnalyticStoreErrors(errors []warnly.AnalyticsStoreErr, user *warnly.User) templ.Component

func ChartAndTable

func ChartAndTable(details *warnly.ProjectDetails, isHtmx bool) templ.Component

func Discussion

func Discussion(discussion *warnly.Discussion) templ.Component

func DiscussionMessages

func DiscussionMessages(discussion *warnly.Discussion) templ.Component

func EditAlert added in v0.5.0

func EditAlert(user *warnly.User, projects []warnly.Project, alert *warnly.Alert) templ.Component

func EditAlertContent added in v0.5.0

func EditAlertContent(user *warnly.User, projects []warnly.Project, alert *warnly.Alert) templ.Component

func EditAlertHtmx added in v0.5.0

func EditAlertHtmx(user *warnly.User, projects []warnly.Project, alert *warnly.Alert) templ.Component

func ErrorsHtmx

func ErrorsHtmx(errors []warnly.AnalyticsStoreErr) templ.Component

func Events

func Fields

func GetIssue

func GetIssue(issue *warnly.IssueDetails, user *warnly.User, source string) templ.Component

func GetIssueContent

func GetIssueContent(issue *warnly.IssueDetails, user *warnly.User) templ.Component

func GetIssueHtmx

func GetIssueHtmx(issue *warnly.IssueDetails, user *warnly.User, source string) templ.Component

func GettingStarted

func GettingStarted(projectInfo *warnly.ProjectInfo) templ.Component

func InDevelopment

func InDevelopment() templ.Component

func Index

func Index(res *warnly.ListIssuesResult, user *warnly.User) templ.Component

func IssueListTable

func IssueListTable(details *warnly.ProjectDetails, isHtmx bool) templ.Component

func Issues

Issues is the main template that includes filters header and issue list body

func IssuesBody

func IssuesBody(res *warnly.ListIssuesResult) templ.Component

IssuesBody - the issues list and pagination that gets updated via HTMX

func IssuesFiltersAndBody

func IssuesFiltersAndBody(res *warnly.ListIssuesResult) templ.Component

IssuesFiltersAndBody contains the filters and the body - used for HTMX updates

func IssuesHtmx

func IssuesHtmx(res *warnly.ListIssuesResult) templ.Component

func Layout

func Layout(title string, content templ.Component, activePage string, user *warnly.User) templ.Component

func Login added in v0.2.0

func Login(errorMsg string, authURL string, providerName string, isDemo bool) templ.Component

func OnCall

func OnCall(user *warnly.User) templ.Component

func OnCallHtmx

func OnCallHtmx() templ.Component

func Platform

func Platform(teams []warnly.Team, user *warnly.User) templ.Component

func PlatformHtmx

func PlatformHtmx(teams []warnly.Team) templ.Component

func ProjectContentHtmx

func ProjectContentHtmx(user *warnly.User, res *warnly.ListProjectsResult) templ.Component

func ProjectContents

func ProjectContents(user *warnly.User, res *warnly.ListProjectsResult) templ.Component

func ProjectDetails

func ProjectDetails(details *warnly.ProjectDetails, user *warnly.User) templ.Component

func ProjectDetailsHtmx

func ProjectDetailsHtmx(details *warnly.ProjectDetails, user *warnly.User, isHtmx bool) templ.Component

func ProjectGrid

func ProjectGrid(res *warnly.ListProjectsResult) templ.Component

func ProjectSettings

func ProjectSettings(project *warnly.Project, user *warnly.User) templ.Component

func ProjectSettingsHtmx

func ProjectSettingsHtmx(project *warnly.Project) templ.Component

func Reports

func Reports(user *warnly.User) templ.Component

func ReportsHtmx

func ReportsHtmx() templ.Component

func Schema

func Schema(schemas []warnly.Schema, user *warnly.User) templ.Component

func SchemaHtmx

func SchemaHtmx(schemas []warnly.Schema) templ.Component

func ServerError

func ServerError(code string, statusText string) templ.Component

func Settings

func Settings(data *SettingsData) templ.Component

func SettingsHtmx

func SettingsHtmx(data *SettingsData) templ.Component

func System

func System(queries []warnly.SQLQuery, isPartial bool, user *warnly.User) templ.Component

func SystemHtmx

func SystemHtmx(queries []warnly.SQLQuery, _ bool) templ.Component

func Teammates

func Teammates(teammates []warnly.Teammate) templ.Component

func Toast

func Toast() templ.Component

Types

type SettingsData added in v0.5.0

type SettingsData struct {
	User    *warnly.User
	Webhook *warnly.WebhookConfigWithSecret
}

Jump to