Documentation
¶
Overview ¶
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
Index ¶
- Constants
- func AddNewAlert(user *warnly.User, projects []warnly.Project) templ.Component
- func AddNewAlertContent(user *warnly.User, projects []warnly.Project) templ.Component
- func AddNewAlertHtmx(user *warnly.User, projects []warnly.Project) templ.Component
- func Alerts(res *warnly.ListAlertsResult) templ.Component
- func AlertsBody(res *warnly.ListAlertsResult) templ.Component
- func AlertsFiltersAndBody(res *warnly.ListAlertsResult) templ.Component
- func AlertsHtmx(res *warnly.ListAlertsResult) templ.Component
- func AnalyticStoreErrors(errors []warnly.AnalyticsStoreErr, user *warnly.User) templ.Component
- func ChartAndTable(details *warnly.ProjectDetails, isHtmx bool) templ.Component
- func Discussion(discussion *warnly.Discussion) templ.Component
- func DiscussionMessages(discussion *warnly.Discussion) templ.Component
- func EditAlert(user *warnly.User, projects []warnly.Project, alert *warnly.Alert) templ.Component
- func EditAlertContent(user *warnly.User, projects []warnly.Project, alert *warnly.Alert) templ.Component
- func EditAlertHtmx(user *warnly.User, projects []warnly.Project, alert *warnly.Alert) templ.Component
- func ErrorsHtmx(errors []warnly.AnalyticsStoreErr) templ.Component
- func Events(res *warnly.ListEventsResult) templ.Component
- func Fields(res *warnly.ListFieldsResult) templ.Component
- func GetIssue(issue *warnly.IssueDetails, user *warnly.User, source string) templ.Component
- func GetIssueContent(issue *warnly.IssueDetails, user *warnly.User) templ.Component
- func GetIssueHtmx(issue *warnly.IssueDetails, user *warnly.User, source string) templ.Component
- func GettingStarted(projectInfo *warnly.ProjectInfo) templ.Component
- func InDevelopment() templ.Component
- func Index(res *warnly.ListIssuesResult, user *warnly.User) templ.Component
- func IssueListTable(details *warnly.ProjectDetails, isHtmx bool) templ.Component
- func Issues(res *warnly.ListIssuesResult) templ.Component
- func IssuesBody(res *warnly.ListIssuesResult) templ.Component
- func IssuesFiltersAndBody(res *warnly.ListIssuesResult) templ.Component
- func IssuesHtmx(res *warnly.ListIssuesResult) templ.Component
- func Layout(title string, content templ.Component, activePage string, user *warnly.User) templ.Component
- func Login(errorMsg string, authURL string, providerName string, isDemo bool) templ.Component
- func OnCall(user *warnly.User) templ.Component
- func OnCallHtmx() templ.Component
- func Platform(teams []warnly.Team, user *warnly.User) templ.Component
- func PlatformHtmx(teams []warnly.Team) templ.Component
- func ProjectContentHtmx(user *warnly.User, res *warnly.ListProjectsResult) templ.Component
- func ProjectContents(user *warnly.User, res *warnly.ListProjectsResult) templ.Component
- func ProjectDetails(details *warnly.ProjectDetails, user *warnly.User) templ.Component
- func ProjectDetailsHtmx(details *warnly.ProjectDetails, user *warnly.User, isHtmx bool) templ.Component
- func ProjectGrid(res *warnly.ListProjectsResult) templ.Component
- func ProjectSettings(project *warnly.Project, user *warnly.User) templ.Component
- func ProjectSettingsHtmx(project *warnly.Project) templ.Component
- func Reports(user *warnly.User) templ.Component
- func ReportsHtmx() templ.Component
- func Schema(schemas []warnly.Schema, user *warnly.User) templ.Component
- func SchemaHtmx(schemas []warnly.Schema) templ.Component
- func ServerError(code string, statusText string) templ.Component
- func Settings(data *SettingsData) templ.Component
- func SettingsHtmx(data *SettingsData) templ.Component
- func System(queries []warnly.SQLQuery, isPartial bool, user *warnly.User) templ.Component
- func SystemHtmx(queries []warnly.SQLQuery, _ bool) templ.Component
- func Teammates(teammates []warnly.Teammate) templ.Component
- func Toast() templ.Component
- type SettingsData
Constants ¶
const ( AlertsTitle = "Alerts" AnalyticsTitle = "Analytics" IssueDetailsTitle = "Issue Details" IssuesTitle = "Issues" OnCallTitle = "OnCall" NewProjectTitle = "New project" ProjectOverviewTitle = "Project overview" ReportsTitle = "Reports" SettingsTitle = "Settings" ProjectsTitle = "Projects" ProjectSettingsTitle = "Project settings" SchemaTitle = "Schema" QueriesTitle = "Queries" AnalyticsErrorTitle = "Errors" InternalErrorTitle = "Internal Error" )
const AppName = "Warnly"
Variables ¶
This section is empty.
Functions ¶
func AddNewAlert ¶ added in v0.5.0
func AddNewAlertContent ¶ added in v0.5.0
func AddNewAlertHtmx ¶ added in v0.5.0
func Alerts ¶ added in v0.5.0
func Alerts(res *warnly.ListAlertsResult) templ.Component
Alerts is the main template that includes filters header and alert list body
func AlertsBody ¶ added in v0.5.0
func AlertsBody(res *warnly.ListAlertsResult) templ.Component
AlertsBody - the alerts list and pagination that gets updated via HTMX
func AlertsFiltersAndBody ¶ added in v0.5.0
func AlertsFiltersAndBody(res *warnly.ListAlertsResult) templ.Component
AlertsFiltersAndBody contains the filters and the body - used for HTMX updates
func AlertsHtmx ¶ added in v0.5.0
func AlertsHtmx(res *warnly.ListAlertsResult) templ.Component
func AnalyticStoreErrors ¶
func ChartAndTable ¶
func ChartAndTable(details *warnly.ProjectDetails, isHtmx bool) templ.Component
func Discussion ¶
func Discussion(discussion *warnly.Discussion) templ.Component
func DiscussionMessages ¶
func DiscussionMessages(discussion *warnly.Discussion) templ.Component
func EditAlertContent ¶ added in v0.5.0
func EditAlertHtmx ¶ added in v0.5.0
func ErrorsHtmx ¶
func ErrorsHtmx(errors []warnly.AnalyticsStoreErr) templ.Component
func GetIssueContent ¶
func GetIssueHtmx ¶
func GettingStarted ¶
func GettingStarted(projectInfo *warnly.ProjectInfo) templ.Component
func InDevelopment ¶
func IssueListTable ¶
func IssueListTable(details *warnly.ProjectDetails, isHtmx bool) templ.Component
func Issues ¶
func Issues(res *warnly.ListIssuesResult) templ.Component
Issues is the main template that includes filters header and issue list body
func IssuesBody ¶
func IssuesBody(res *warnly.ListIssuesResult) templ.Component
IssuesBody - the issues list and pagination that gets updated via HTMX
func IssuesFiltersAndBody ¶
func IssuesFiltersAndBody(res *warnly.ListIssuesResult) templ.Component
IssuesFiltersAndBody contains the filters and the body - used for HTMX updates
func IssuesHtmx ¶
func IssuesHtmx(res *warnly.ListIssuesResult) templ.Component
func OnCallHtmx ¶
func ProjectContentHtmx ¶
func ProjectContents ¶
func ProjectDetails ¶
func ProjectDetailsHtmx ¶
func ProjectGrid ¶
func ProjectGrid(res *warnly.ListProjectsResult) templ.Component
func ProjectSettings ¶
func ReportsHtmx ¶
func Settings ¶
func Settings(data *SettingsData) templ.Component
func SettingsHtmx ¶
func SettingsHtmx(data *SettingsData) templ.Component
Types ¶
type SettingsData ¶ added in v0.5.0
type SettingsData struct {
User *warnly.User
Webhook *warnly.WebhookConfigWithSecret
}
Source Files
¶
- add_alert_templ.go
- alert_templ.go
- analytic_store_errors_templ.go
- discussions_templ.go
- edit_alert_templ.go
- events_templ.go
- fields_templ.go
- get_issue_templ.go
- getting_started_templ.go
- indevelopment_templ.go
- index_templ.go
- issues_templ.go
- layout_templ.go
- login_templ.go
- oncall_templ.go
- platform_templ.go
- project_details_templ.go
- project_settings_templ.go
- project_templ.go
- reports_templ.go
- schema_templ.go
- server_error_templ.go
- settings_templ.go
- system_templ.go
- teammates_templ.go
- toast_templ.go